@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H
+#define QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H
+
 #define QT_FEATURE_pdf_v8 1
 
 #define QT_FEATURE_pdf_xfa 1
@@ -14,3 +17,5 @@
 
 #define QT_FEATURE_pdf_static_runtime -1
 
+
+#endif // QT_FEATURES_Pdf_src_pdf_qtpdf_config_p_h_H
